@@ -79,7 +79,7 @@ geocode_reverse_init (GeocodeReverse *object)
 	object->priv = G_TYPE_INSTANCE_GET_PRIVATE ((object), GEOCODE_TYPE_REVERSE, GeocodeReversePrivate);
 	object->priv->ht = g_hash_table_new_full (g_str_hash, g_str_equal,
 						  g_free, g_free);
-	object->priv->soup_session = _geocode_glib_build_soup_session ();
+        object->priv->soup_session = soup_session_new ();
 }
 
 /**
@@ -373,7 +373,7 @@ get_resolve_query_for_params (GHashTable  *orig_ht)
 	g_hash_table_destroy (ht);
 	g_free (locale);
 
-	uri = g_strdup_printf ("http://nominatim.gnome.org/reverse?%s", params);
+	uri = g_strdup_printf ("https://nominatim.gnome.org/reverse?%s", params);
 	g_free (params);
 
 	ret = soup_message_new ("GET", uri);
